@@ -11,19 +11,19 @@ use nuance::Nuance;
 fn main() -> Result<()> {
     let mut power_preference = PowerPreference::LowPower;
     for arg in std::env::args() {
-        match arg.as_str() {
-            "-H" => {
-                power_preference = PowerPreference::HighPerformance;
-            }
-            _ => {}
+        if arg.as_str() == "-H" {
+            power_preference = PowerPreference::HighPerformance;
         }
     }
 
+    puffin::set_scopes_on(true);
+
     TermLogger::init(
         LevelFilter::Debug,
         ConfigBuilder::new()
             .set_target_level(LevelFilter::Error)
-            .add_filter_ignore_str("naga::front::spv")
+            .add_filter_ignore_str("naga::front")
+            .add_filter_ignore_str("naga::valid::function")
             .add_filter_ignore_str("naga::valid::interface")
             .add_filter_ignore_str("wgpu_core::instance")
             .add_filter_ignore_str("wgpu_core::device")
@@ -31,6 +31,7 @@ fn main() -> Result<()> {
             .add_filter_ignore_str("wgpu_core::command")
             .add_filter_ignore_str("wgpu_core::hub")
             .add_filter_ignore_str("gfx_backend_vulkan")
+            .add_filter_ignore_str("gfx_backend_dx12")
             .build(),
         TerminalMode::Stdout,
         ColorChoice::Auto,
@@ -43,14 +44,14 @@ fn main() -> Result<()> {
     // Create the window
     let builder = WindowBuilder::new()
         .with_title("Nuance")
-        .with_inner_size(LogicalSize::new(800, 600))
+        .with_inner_size(LogicalSize::new(1280, 720))
         .with_resizable(false)
         .with_visible(true);
     let window = builder.build(&event_loop)?;
 
     // Going async !
     let app = futures_executor::block_on(Nuance::init(window, power_preference))?;
-    futures_executor::block_on(app.run(event_loop))?;
+    app.run(event_loop)?;
 
     Ok(())
 }
